# Purpose of `stravawizard` package

[Disclaimer] : this is a draft, examples will be given in the next versions of the package.

This packages offers 2 clients in order to work with Strava API:
* `stravauth_cli`: allows user to deal easily with Strava oauth authentification. Requires all credentials of a declared Strava app (client id, client secret and redirect uri) in order to work properly.
* `stravapi_cli`: allows user to use directly Strava API, given an access token.


# Install

`pip install stravawizard`


# Use case

[To come]
